@@ -15,12 +15,18 @@ int fileError(void* h);
 // Returns a negative number if not a file (e.g. directory or device)
 int fileSize(void* h);
 
+// Return a negative number if not a file (e.g. directory or device)
+VAL fileAccessTime(void* h);
+VAL fileModifiedTime(void* h);
+VAL fileStatusTime(void* h);
+
 void* idris_dirOpen(char* dname);
 void idris_dirClose(void* h);
 char* idris_nextDirEntry(void* h);
 
 // Create a directory; return 0 on success or -1 on failure
 int idris_mkdir(char* dname);
+int idris_chdir(char* dname);
 
 // Return 0 if ok, or -1 if there was an error with the given directory
 // (like ferror)
